@@ -1,6 +1,6 @@
 from netbox.forms import NetBoxModelForm
 from pyrsistent import v
-from .models import Risk, RiskRelation#, RiskAssignment
+from .models import Risk, RiskRelation, RiskAssignment
 from utilities.forms import (
     BootstrapMixin, DynamicModelChoiceField)
 from django import forms
@@ -24,3 +24,17 @@ class RiskRelationForm(NetBoxModelForm):
         model = RiskRelation
         fields = ('name', 'CN', 'DistinguishedName', 'ad_guid', 'ad_description', 'description')
 
+
+class RiskAssignmentForm(BootstrapMixin, forms.ModelForm):
+    risk = DynamicModelChoiceField(
+        queryset=Risk.objects.all()
+    )
+    relation = DynamicModelChoiceField(
+        queryset=RiskRelation.objects.all()
+    )
+
+    class Meta:
+        model = RiskAssignment
+        fields = (
+            'risk', 'relation',
+        )
